* REPLICATION DATA FOR "DYNAMIC COALITIONS AND COMMUNICATION: PRIVATE VERSUS PUBLIC NEGOTIATIONS" BY DAVE BARON, RENEE BOWEN AND SALVATORE NUNNARI
* LAST UPDATE: 29 AUGUST 2017

* LOAD RAW DATASET WITHOUT CHAT MESSAGES
* NOTE: NEED TO CHANGE PATH BELOW TO POINT TO DATASET ON LOCAL DRIVE

use "bbn-dynbargchat-nochatdata-raw-29aug17.dta", clear
set more off

* CODEBOOK FOR RAW DATA VARIABLES
* expid: experimental session ID (1-6)
* treatment: treatment in session ("BASELINE", "PUBLIC", "PRIVATE")
* matchid: match ID (1-4)
* groupid: group ID
* roundid: round ID
* index: committee member ID (0-2), randomly reassigned at the beginning of every match
* proposer: index of committee member who proposes in this round
* statusquo: status quo allocation in this round
* proposal: proposed allocation in this round
* vote: vote of this committee member ("Proposal" or "Status Quo")
* votesforsq: total votes in favor of status quo
* accepted: dummy for accepted proposal
* voteoutcome: allocation implemented in this period
* p_pork0: transfer to member 0 in proposal
* p_pork1: transfer to member 1 in proposal
* p_pork2: transfer to member 2 in proposal
* sq_pork0: transfer to member 0 in status quo 
* sq_pork1: transfer to member 1 in status quo 
* sq_pork2: transfer to member 2 in status quo 
* o_pork0: transfer to member 0 in outcome 
* o_pork1: transfer to member 1 in outcome 
* o_pork2: transfer to member 2 in outcome 
* o_porktoprop: transfer to proposer in outcome 
* sq_porktoprop: transfer to proposer in status quo
* p_porktoprop: transfer to proposer in proposal
* p_porktome: transfer to this member in proposal
* sq_porktome: transfer to this member in status quo
* o_porktome: transfer to this member in outcome
* o_pork1st: highest transfer in outcome
* o_pork2nd: second highest transfer in outcome
* o_pork3rd: third highest transfer in outcome

**************************************
* CREATION OF VARIABLES FOR ANALYSES *
**************************************

* UNIQUE ID FOR COMMITTEES
egen uniquegroupid=concat(expid matchid groupid), punct(_)
egen uniquegroupid_num = group(uniquegroupid)

* UNIQUE ID FOR COMMITTEE MEMBER
egen uniquememberid=concat(uniquegroupid index), punct(_)
egen uniquememberid_num = group(uniquememberid)

* VARIABLE FOR OUTCOME TYPE, 5 CATEGORIES (DICTATOR, MWC EVEN, MWC UNEVEN, UNIVERSAL EVEN, UNOVERSAL UNEVEN)
gen o_type5=""
replace o_type5="UNIVERSAL EVEN" if min(o_pork1,o_pork2,o_pork0)==20
replace o_type5="UNIVERSAL UNEVEN" if min(o_pork1,o_pork2,o_pork0)>9 & min(o_pork1,o_pork2,o_pork0)<20
replace o_type5="DICTATOR" if o_pork0>49
replace o_type5="DICTATOR" if o_pork1>49
replace o_type5="DICTATOR" if o_pork2>49
replace o_type5="MWC EVEN" if o_type5=="" & (o_pork0==o_pork1 | o_pork1==o_pork2 | o_pork0==o_pork2)
replace o_type5="MWC UNEVEN" if o_type5=="" 

* VARIABLE FOR OUTCOME TYPE, 3 CATEGORIES (DICTATOR, MWC, UNIVERSAL)
gen o_type3=o_type5
replace o_type3="UNIVERSAL" if o_type5=="UNIVERSAL EVEN"
replace o_type3="UNIVERSAL" if o_type5=="UNIVERSAL UNEVEN"
replace o_type3="MWC" if o_type5=="MWC EVEN"
replace o_type3="MWC" if o_type5=="MWC UNEVEN"

* VARIABLE FOR OUTCOME TYPE, 7 CATEGORIES (DICTATOR 1, DICTATOR 2, DICTATOR 3, MWC 1 & 2, MWC 1 & 3, MWC 2 & 3, UNIVERSAL)
gen o_type7=o_type5
replace o_type7="DICTATOR1" if o_pork0>49
replace o_type7="DICTATOR2" if o_pork1>49
replace o_type7="DICTATOR3" if o_pork2>49
replace o_type7="MWC12" if (o_type5=="MWC EVEN" | o_type5=="MWC UNEVEN") & o_pork0>=o_pork2 & o_pork1>=o_pork2
replace o_type7="MWC13" if (o_type5=="MWC EVEN" | o_type5=="MWC UNEVEN") & o_pork0>=o_pork1 & o_pork2>=o_pork1
replace o_type7="MWC23" if (o_type5=="MWC EVEN" | o_type5=="MWC UNEVEN") & o_pork1>=o_pork0 & o_pork2>=o_pork0
replace o_type7="UNIVERSAL" if o_type5=="UNIVERSAL EVEN"
replace o_type7="UNIVERSAL" if o_type5=="UNIVERSAL UNEVEN"

* VARIABLE FOR STATUS QUO TYPE, 5 CATEGORIES (DICTATOR, MWC EVEN, MWC UNEVEN, UNIVERSAL EVEN, UNOVERSAL UNEVEN)
gen sq_type5=""
replace sq_type5="UNIVERSAL EVEN" if min(sq_pork1,sq_pork2,sq_pork0)==20
replace sq_type5="UNIVERSAL UNEVEN" if min(sq_pork1,sq_pork2,sq_pork0)>9 & min(sq_pork1,sq_pork2,sq_pork0)<20
replace sq_type5="DICTATOR" if sq_pork0>49
replace sq_type5="DICTATOR" if sq_pork1>49
replace sq_type5="DICTATOR" if sq_pork2>49
replace sq_type5="MWC EVEN" if sq_type5=="" & (sq_pork0==sq_pork1 | sq_pork1==sq_pork2 | sq_pork0==sq_pork2)
replace sq_type5="MWC UNEVEN" if sq_type5=="" 

* VARIABLE FOR STATUS QUO TYPE, 3 CATEGORIES (DICTATOR, MWC, UNIVERSAL)
gen sq_type3=sq_type5
replace sq_type3="UNIVERSAL" if sq_type5=="UNIVERSAL EVEN"
replace sq_type3="UNIVERSAL" if sq_type5=="UNIVERSAL UNEVEN"
replace sq_type3="MWC" if sq_type5=="MWC EVEN"
replace sq_type3="MWC" if sq_type5=="MWC UNEVEN"

* VARIABLE FOR STATUS QUO TYPE, 7 CATEGORIES (DICTATOR, MWC EVEN, MWC UNEVEN, UNIVERSAL EVEN, UNOVERSAL UNEVEN)
gen sq_type7=sq_type5
replace sq_type7="DICTATOR1" if sq_pork0>49
replace sq_type7="DICTATOR2" if sq_pork1>49
replace sq_type7="DICTATOR3" if sq_pork2>49
replace sq_type7="MWC12" if (sq_type5=="MWC EVEN" | sq_type5=="MWC UNEVEN") & sq_pork0>=sq_pork2 & sq_pork1>=sq_pork2
replace sq_type7="MWC13" if (sq_type5=="MWC EVEN" | sq_type5=="MWC UNEVEN") & sq_pork0>=sq_pork1 & sq_pork2>=sq_pork1
replace sq_type7="MWC23" if (sq_type5=="MWC EVEN" | sq_type5=="MWC UNEVEN") & sq_pork1>=sq_pork0 & sq_pork2>=sq_pork0
replace sq_type7="UNIVERSAL" if sq_type5=="UNIVERSAL EVEN"
replace sq_type7="UNIVERSAL" if sq_type5=="UNIVERSAL UNEVEN"

* DUMMIES FOR OUTCOME TYPE
gen o_type_dict=0
replace o_type_dict=1 if o_type3=="DICTATOR"
gen o_type_mwc=0
replace o_type_mwc=1 if o_type3=="MWC"
gen o_type_mwc_even=0
replace o_type_mwc_even=1 if o_type5=="MWC EVEN"
gen o_type_mwc_uneven=0
replace o_type_mwc_uneven=1 if o_type5=="MWC UNEVEN"
gen o_type_u=0
replace o_type_u=1 if o_type3=="UNIVERSAL"
gen o_type_u_even=0
replace o_type_u_even=1 if o_type5=="UNIVERSAL EVEN"
gen o_type_u_uneven=0
replace o_type_u_uneven=1 if o_type5=="UNIVERSAL UNEVEN"

* VARIABLE FOR STATUS QUO TYPE, 3 CATEGORIES, ALTERNATIVE CLASSIFICATION
gen sq_type3_alt="OTHER"
replace sq_type3_alt="UNIVERSAL" if sq_pork0>14 & sq_pork1>14 & sq_pork2>14
replace sq_type3_alt="DICTATOR" if sq_pork0>49 | sq_pork1>49 | sq_pork2>49
replace sq_type3_alt="MWC" if sq_type3_alt=="OTHER" & sq_pork1>19 & sq_pork2>19 & sq_pork0<15
replace sq_type3_alt="MWC" if sq_type3_alt=="OTHER" & sq_pork0>19 & sq_pork2>19 & sq_pork1<15
replace sq_type3_alt="MWC" if sq_type3_alt=="OTHER" & sq_pork0>19 & sq_pork1>19 & sq_pork2<15

* VARIABLE FOR OUTCOME TYPE, 3 CATEGORIES, ALTERNATIVE CLASSIFICATION
gen o_type3_alt="OTHER"
replace o_type3_alt="UNIVERSAL" if o_pork0>14 & o_pork1>14 & o_pork2>14
replace o_type3_alt="DICTATOR" if o_pork0>49 | o_pork1>49 | o_pork2>49
replace o_type3_alt="MWC" if o_type3_alt=="OTHER" & o_pork1>19 & o_pork2>19 & o_pork0<15
replace o_type3_alt="MWC" if o_type3_alt=="OTHER" & o_pork0>19 & o_pork2>19 & o_pork1<15
replace o_type3_alt="MWC" if o_type3_alt=="OTHER" & o_pork0>19 & o_pork1>19 & o_pork2<15

* VARIABLE FOR OUTCOME TYPE, 5 CATEGORIES, ALTERNATIVE CLASSIFICATION
gen o_type5_alt=o_type3_alt
replace o_type5_alt="UNIVERSAL EVEN" if o_pork0==20 & o_pork1==20 & o_pork2==20
replace o_type5_alt="UNIVERSAL UNEVEN" if o_type5_alt=="UNIVERSAL"
replace o_type5_alt="MWC EVEN" if o_type5_alt=="MWC" & (o_pork0==o_pork1 | o_pork1==o_pork2 | o_pork0==o_pork2)
replace o_type5_alt="MWC UNEVEN" if o_type5_alt=="MWC"

* DUMMIES FOR OUTCOME TYPE, ALTERNATIVE CLASSIFICATION
gen o_type_dict_alt=0
replace o_type_dict_alt=1 if o_type3_alt=="DICTATOR"
gen o_type_mwc_alt=0
replace o_type_mwc_alt=1 if o_type3_alt=="MWC"
gen o_type_mwc_even_alt=0
replace o_type_mwc_even_alt=1 if o_type5_alt=="MWC EVEN"
gen o_type_mwc_uneven_alt=0
replace o_type_mwc_uneven_alt=1 if o_type5_alt=="MWC UNEVEN"
gen o_type_u_alt=0
replace o_type_u_alt=1 if o_type3_alt=="UNIVERSAL"
gen o_type_u_even_alt=0
replace o_type_u_even_alt=1 if o_type5_alt=="UNIVERSAL EVEN"
gen o_type_u_uneven_alt=0
replace o_type_u_uneven_alt=1 if o_type5_alt=="UNIVERSAL UNEVEN"
gen o_type_other_alt=0
replace o_type_other_alt=1 if o_type3_alt=="OTHER"

* DUMMY FOR PRIVATE COMMUNICATION TREATMENT VS. ALL OTHER TREATMENTS
gen privatedummy=0
replace privatedummy=1 if treatment=="PRIVATE"

* DUMMY FOR PUBLIC COMMUNICATION TREATMENT VS. ALL OTHER TREATMENTS
gen publicdummy=0
replace publicdummy=1 if treatment=="PUBLIC"

* DUMMY FOR PRIVATE COMMUNICATION TREATMENT VS. BASELINE
gen priv_vs_baseline=0
replace priv_vs_baseline=1 if treatment=="PRIVATE"
replace priv_vs_baseline=. if treatment=="PUBLIC"

* DUMMY FOR PUBLIC COMMUNICATION TREATMENT VS. BASELINE
gen pub_vs_baseline=0
replace pub_vs_baseline=. if treatment=="PRIVATE"
replace pub_vs_baseline=1 if treatment=="PUBLIC"

* DUMMY FOR PROPOSER
gen proposerdummy=0
replace proposerdummy=1 if index==proposer

* INTERACTION BETWEEN PROPOSER AND PRIVATE TREATMENT
gen privproposer=privatedummy*proposerdummy
* INTERACTION BETWEEN PROPOSER AND PUBLIC TREATMENT
gen publproposer=publicdummy*proposerdummy

* LENGTH OF A GAME (IN PERIODS)
bys expid matchid: egen matchlength=max(roundid)

* DUMMY FOR OUTCOME STABILITY (STRONG DEFINITION)
gen strongcoalition=0
replace strongcoalition=1 if voteoutcome==statusquo
replace strongcoalition=. if roundid==1

* DUMMY FOR OUTCOME STABILITY (WEAK DEFINITION)
gen weakcoalition=0
replace weakcoalition=1 if o_type7==sq_type7
replace weakcoalition=. if roundid==1

* VARIABLES ON INEQUALITY OF STATUS QUO, PROPOSED AND IMPLEMENTED ALLOCATIONS IN A COMMITTEE IN A PERIOD
gen o_ginicoeff=(1/3)*(3+1-(2*(3+1-1)*o_pork3rd)/60-(2*(3+1-2)*o_pork2nd)/60-(2*(3+1-3)*o_pork1st)/60)
gen p_pork1st=max(p_pork0, p_pork1, p_pork2)
gen p_pork3rd=min(p_pork0, p_pork1, p_pork2)
gen p_pork2nd=60-p_pork1st-p_pork3rd
gen p_ginicoeff=(1/3)*(3+1-(2*(3+1-1)*p_pork3rd)/60-(2*(3+1-2)*p_pork2nd)/60-(2*(3+1-3)*p_pork1st)/60)
gen sq_pork1st=max(sq_pork0, sq_pork1, sq_pork2)
gen sq_pork3rd=min(sq_pork0, sq_pork1, sq_pork2)
gen sq_pork2nd=60-sq_pork1st-sq_pork3rd
gen sq_ginicoeff=(1/3)*(3+1-(2*(3+1-1)*sq_pork3rd)/60-(2*(3+1-2)*sq_pork2nd)/60-(2*(3+1-3)*sq_pork1st)/60)
bys uniquegroupid: egen tot3_o_pork0=sum(o_pork0)
bys uniquegroupid: egen tot3_o_pork1=sum(o_pork1)
bys uniquegroupid: egen tot3_o_pork2=sum(o_pork2)
gen tot_o_pork0=tot3_o_pork0/3
gen tot_o_pork1=tot3_o_pork1/3
gen tot_o_pork2=tot3_o_pork2/3
gen tot_o_pork=tot_o_pork0+tot_o_pork1+tot_o_pork2
gen tot_o_pork1st=max(tot_o_pork0, tot_o_pork1, tot_o_pork2)
gen tot_o_pork3rd=min(tot_o_pork0, tot_o_pork1, tot_o_pork2)
gen tot_o_pork2nd=tot_o_pork-tot_o_pork1st-tot_o_pork3rd
gen tot_ginicoeff=(1/3)*(3+1-(2*(3+1-1)*tot_o_pork3rd)/tot_o_pork-(2*(3+1-2)*tot_o_pork2nd)/tot_o_pork-(2*(3+1-3)*tot_o_pork1st)/tot_o_pork)

* FRACTION OF OUTCOMES IN A COMMITTEE THAT BELONG TO EACH CATEGORY (POOLING TOGETHER ALL ROUNDS IN THE MATCH)
bys uniquegroupid: egen perc_o_type_dict=mean(o_type_dict)
bys uniquegroupid: egen perc_o_type_mwc=mean(o_type_mwc)
bys uniquegroupid: egen perc_o_type_mwc_even=mean(o_type_mwc_even)
bys uniquegroupid: egen perc_o_type_mwc_uneven=mean(o_type_mwc_uneven)
bys uniquegroupid: egen perc_o_type_u=mean(o_type_u)
bys uniquegroupid: egen perc_o_type_u_even=mean(o_type_u_even)
bys uniquegroupid: egen perc_o_type_u_uneven=mean(o_type_u_uneven)

* VARIABLES ON DIFFERENCES BETWEEN PROPOSAL AND STATUS QUO
gen p_premiumtome=p_porktome-sq_porktome
gen p_premiumtoprop=p_porktoprop-sq_porktoprop
gen p_diffginicoeff=p_ginicoeff-sq_ginicoeff

* DUMMY FOR VOTING IN FAVOR OF PROPOSAL
gen voteyes=1
replace voteyes=0 if vote=="Status Quo"

* ALLOCATION TO ONESELF IN FOLLOWING ROUND
sort expid matchid groupid index roundid
gen o_porktome_tomorrow=.
replace o_porktome_tomorrow=o_porktome[_n+1] if o_porktome_tomorrow==. & roundid<matchlength

* VARIABLES IDENTIFYING PROPOSERS WHO BELONG TO CURRENT COALITION
gen inmemberprop=.
replace inmemberprop=0 if sq_type3=="MWC"
replace inmemberprop=1 if sq_type7=="MWC12" & index==0
replace inmemberprop=1 if sq_type7=="MWC12" & index==1
replace inmemberprop=1 if sq_type7=="MWC13" & index==0
replace inmemberprop=1 if sq_type7=="MWC13" & index==2
replace inmemberprop=1 if sq_type7=="MWC23" & index==1
replace inmemberprop=1 if sq_type7=="MWC23" & index==2
gen priv_inmemberprop=priv_vs_baseline*inmemberprop
gen pub_inmemberprop=pub_vs_baseline*inmemberprop

*********************************
* 5.1 DISTRIBUTION OF RESOURCES *
*********************************

*******************************
* TABLE 2 + ROBUSTNESS CHECKS *
*******************************

* TABLE 2
* ALLOCATION TYPES BY TREATMENT
bys treatment: tab o_type3 if matchid>1 & index==0
bys treatment: tab o_type5 if matchid>1 & index==0

* RANDOM EFFECTS PANEL REGRESSIONS CLUSTERING SE AT SESSION LEVEL
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg o_type_dict priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_even priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_uneven priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_even priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_uneven priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_dict pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_even pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_uneven pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_even pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_uneven pub_vs_baseline if matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7, star(* 0.05 ** 0.01) se b(2) pr2 
esttab est8 est9 est10 est11 est12 est13 est14, star(* 0.05 ** 0.01) se b(2) pr2
restore

* ROBUSTNESS CHECK #1: WHOLE SAMPLE (FOOTNOTE 21)
* ALLOCATION TYPES BY TREATMENT
bys treatment: tab o_type3 if index==0
bys treatment: tab o_type5 if index==0
* RANDOM EFFECTS PANEL REGRESSIONS CLUSTERING SE AT SESSION LEVEL
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg o_type_dict priv_vs_baseline, cluster(expid)
eststo: xtreg o_type_mwc priv_vs_baseline, cluster(expid)
eststo: xtreg o_type_mwc_even priv_vs_baseline, cluster(expid)
eststo: xtreg o_type_mwc_uneven priv_vs_baseline, cluster(expid)
eststo: xtreg o_type_u priv_vs_baseline, cluster(expid)
eststo: xtreg o_type_u_even priv_vs_baseline, cluster(expid)
eststo: xtreg o_type_u_uneven priv_vs_baseline, cluster(expid)
eststo: xtreg o_type_dict pub_vs_baseline, cluster(expid)
eststo: xtreg o_type_mwc pub_vs_baseline, cluster(expid)
eststo: xtreg o_type_mwc_even pub_vs_baseline, cluster(expid)
eststo: xtreg o_type_mwc_uneven pub_vs_baseline, cluster(expid)
eststo: xtreg o_type_u pub_vs_baseline, cluster(expid)
eststo: xtreg o_type_u_even pub_vs_baseline, cluster(expid)
eststo: xtreg o_type_u_uneven pub_vs_baseline, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7, star(* 0.05 ** 0.01) se b(2) pr2 
esttab est8 est9 est10 est11 est12 est13 est14, star(* 0.05 ** 0.01) se b(2) pr2
restore

* ROBUSTNESS CHECK #2: ALTERNATIVE CLASSIFICATION OF ALLOCATIONS (FOONOTE 20 AND TABLE 1 IN ONLINE APPENDIX)
* ALLOCATION TYPES BY TREATMENT 
bys treatment: tab o_type3_alt if matchid>1 & index==0
bys treatment: tab o_type5_alt if matchid>1 & index==0
* RANDOM EFFECTS PANEL REGRESSIONS CLUSTERING SE AT SESSION LEVEL
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg o_type_dict_alt priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_alt priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_even_alt priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_uneven_alt priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_alt priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_even_alt priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_uneven_alt priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_other_alt priv_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_dict_alt pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_alt pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_even_alt pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_mwc_uneven_alt pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_alt pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_even_alt pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_u_uneven_alt pub_vs_baseline if matchid>1, cluster(expid)
eststo: xtreg o_type_other_alt pub_vs_baseline if matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7 est8, star(* 0.05 ** 0.01) se b(2) pr2
esttab est9 est10 est11 est12 est13 est14 est15 est16, star(* 0.05 ** 0.01) se b(2) pr2
restore

* ROBUSTNESS CHECK #3: USING COMMITTEE-MATCH AS UNIT OF ANALYSIS (FOOTNOTE 22)
* MANN-WHITNEY-WILCOXON TESTS 
eststo clear
eststo: reg perc_o_type_dict priv_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_mwc priv_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_mwc_even priv_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_mwc_uneven priv_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_u priv_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_u_even priv_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_u_uneven priv_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_dict pub_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_mwc pub_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_mwc_even pub_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_mwc_uneven pub_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_u pub_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_u_even pub_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
eststo: reg perc_o_type_u_uneven pub_vs_baseline if matchid>1 & roundid==1 & index==0, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7, star(* 0.05 ** 0.01) se b(2) pr2 
esttab est8 est9 est10 est11 est12 est13 est14, star(* 0.05 ** 0.01) se b(2) pr2

***********
* TABLE 3 *
***********

* TABLE 3
* STATIC AND DYNAMIC PROPOSER ADVANTAGE
xtset uniquememberid_num roundid
eststo clear
eststo: xtreg o_porktome sq_porktome privatedummy proposerdummy privproposer if treatment!="PUBLIC" & matchid>1, cluster(expid)
eststo: xtreg o_porktome sq_porktome publicdummy proposerdummy publproposer if treatment!="PRIVATE" & matchid>1, cluster(expid)
eststo: xtreg o_porktome_tomorrow o_porktome privatedummy proposerdummy privproposer if treatment!="PUBLIC" & matchid>1, cluster(expid)
eststo: xtreg o_porktome_tomorrow o_porktome publicdummy proposerdummy publproposer if treatment!="PRIVATE" & matchid>1, cluster(expid)
esttab est1 est2 est3 est4, star(* 0.10 ** 0.05 *** 0.01) se b(2) r2

*************************************************
* TABLE 7 IN ONLINE APPENDIX + ROBUSTNESS CHECK *
*************************************************

sort expid matchid groupid roundid index
gen initialsq_pork0=.
replace initialsq_pork0=sq_pork0 if roundid==1
replace initialsq_pork0=initialsq_pork0[_n-3] if roundid>1
gen initialsq_pork1=.
replace initialsq_pork1=sq_pork1 if roundid==1
replace initialsq_pork1=initialsq_pork1[_n-3] if roundid>1
gen initialsq_pork2=.
replace initialsq_pork2=sq_pork2 if roundid==1
replace initialsq_pork2=initialsq_pork2[_n-3] if roundid>1
gen initialsq_porktome=initialsq_pork0
replace initialsq_porktome=initialsq_pork1 if index==1
replace initialsq_porktome=initialsq_pork2 if index==2

* TABLE 7 IN ONLINE APPENDIX (MENTIONED IN FOOTNOTE 16)
* IRRELEVANCE OF INITIAL STATUS QUO
eststo clear
eststo: tobit o_porktome sq_porktome initialsq_porktome if roundid==2 & matchid>1 & treatment=="BASELINE", ll(0) ul(60) cluster(uniquegroupid)
eststo: tobit o_porktome sq_porktome initialsq_porktome if roundid==2 & matchid>1 & treatment=="PRIVATE", ll(0) ul(60) cluster(uniquegroupid)
eststo: tobit o_porktome sq_porktome initialsq_porktome if roundid==2 & matchid>1 & treatment=="PUBLIC", ll(0) ul(60) cluster(uniquegroupid)
esttab est1 est2 est3, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2

* ROBUSTNESS CHECK: WHOLE SAMPLE (MENTIONED IN CAPTION TO TABLE 7 IN ONLINE APPENDIX)
eststo clear
eststo: tobit o_porktome sq_porktome initialsq_porktome if roundid==2 & treatment=="BASELINE", ll(0) ul(60) cluster(uniquegroupid)
eststo: tobit o_porktome sq_porktome initialsq_porktome if roundid==2 & treatment=="PRIVATE", ll(0) ul(60) cluster(uniquegroupid)
eststo: tobit o_porktome sq_porktome initialsq_porktome if roundid==2 & treatment=="PUBLIC", ll(0) ul(60) cluster(uniquegroupid)
esttab est1 est2 est3, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2

***********************
* 5.3 VOTING BEHAVIOR *
***********************

* TABLE 6
eststo clear
eststo: probit voteyes p_premiumtome p_premiumtoprop p_diffginicoeff if matchid>1 & treatment=="BASELINE" & proposer!=index, cluster(expid)
eststo: probit voteyes p_premiumtome p_premiumtoprop p_diffginicoeff if matchid>1 & treatment=="PUBLIC" & proposer!=index, cluster(expid)
eststo: probit voteyes p_premiumtome p_premiumtoprop p_diffginicoeff if matchid>1 & treatment=="PRIVATE" & proposer!=index, cluster(expid)
esttab est1 est2 est3, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2

****************************************
* 5.2 COALITION FORMATION AND DURATION *
****************************************

*******************************
* TABLE 4 + ROBUSTNESS CHECKS *
*******************************

* TABLE 4
* ALLOCATION STABILITY BY TREATMENT
bys treatment: tab strongcoalition if sq_type3=="DICTATOR" & matchid>1 & index==0
bys treatment: tab strongcoalition if sq_type3=="MWC" & matchid>1 & index==0
bys treatment: tab strongcoalition if sq_type3=="UNIVERSAL" & matchid>1 & index==0
* RANDOM EFFECTS PANEL REGRESSIONS CLUSTERING SE AT THE SESSION LEVEL 
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3=="DICTATOR" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3=="UNIVERSAL" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3=="DICTATOR" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3=="UNIVERSAL" & matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6, star(* 0.05 ** 0.01) se b(2)
restore

* ROBUSTNESS CHECK #1: PROBIT REGRESSION CLUSTERING SE AT THE SESSION LEVEL (CAPTION OF TABLE 4)
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: probit strongcoalition priv_vs_baseline if sq_type3=="DICTATOR" & matchid>1, cluster(expid)
eststo: probit strongcoalition priv_vs_baseline if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: probit strongcoalition priv_vs_baseline if sq_type3=="UNIVERSAL" & matchid>1, cluster(expid)
eststo: probit strongcoalition pub_vs_baseline if sq_type3=="DICTATOR" & matchid>1, cluster(expid)
eststo: probit strongcoalition pub_vs_baseline if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: probit strongcoalition pub_vs_baseline if sq_type3=="UNIVERSAL" & matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6, star(* 0.05 ** 0.01) se b(2)
restore

* ROBUSTNESS CHECK #2: SENSITIVITY TO IDENTITY OF PROPOSER (FOOTNOTE 28)
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg strongcoalition priv_vs_baseline inmemberprop priv_inmemberprop if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline inmemberprop pub_inmemberprop if sq_type3=="MWC" & matchid>1, cluster(expid)
esttab est1 est2, star(* 0.05 ** 0.01) se b(2)
restore

* ROBUSTNESS CHECK #3: WHOLE SAMPLE (FOOTNOTE 27)
* ALLOCATION STABILITY BY TREATMENT
bys treatment: tab strongcoalition if sq_type3=="DICTATOR" & index==0
bys treatment: tab strongcoalition if sq_type3=="MWC" & index==0
bys treatment: tab strongcoalition if sq_type3=="UNIVERSAL" & index==0
* RE PANEL REGRESSIONS CLUSTERING SE AT THE SESSION LEVEL 
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3=="DICTATOR", cluster(expid)
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3=="MWC", cluster(expid)
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3=="UNIVERSAL", cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3=="DICTATOR", cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3=="MWC", cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3=="UNIVERSAL", cluster(expid)
esttab est1 est2 est3 est4 est5 est6, star(* 0.05 ** 0.01) se b(2)
restore

* ROBUSTNESS CHECK #4: ALTERNATIVE CLASSIFICATION OF ALLOCATIONS (TABLE 2 IN ONLINE APPENDIX)
* ALLOCATION STABILITY BY TREATMENT
bys treatment: tab strongcoalition if sq_type3_alt=="DICTATOR" & matchid>1 & index==0
bys treatment: tab strongcoalition if sq_type3_alt=="MWC" & matchid>1 & index==0
bys treatment: tab strongcoalition if sq_type3_alt=="UNIVERSAL" & matchid>1 & index==0
bys treatment: tab strongcoalition if sq_type3_alt=="OTHER" & matchid>1 & index==0
* RE PANEL REGRESSIONS CLUSTERING SE AT THE SESSION LEVEL 
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3_alt=="DICTATOR" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3_alt=="MWC" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition priv_vs_baseline if sq_type3_alt=="UNIVERSAL" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3_alt=="DICTATOR" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3_alt=="MWC" & matchid>1, cluster(expid)
eststo: xtreg strongcoalition pub_vs_baseline if sq_type3_alt=="UNIVERSAL" & matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6, star(* 0.05 ** 0.01) se b(2)
restore
* PROBIT REGRESSIONS CLUSTERING SE AT THE SESSION LEVEL 
preserve
keep if index==0
eststo clear
eststo: probit strongcoalition priv_vs_baseline if sq_type3_alt=="DICTATOR" & matchid>1, cluster(expid)
eststo: probit strongcoalition priv_vs_baseline if sq_type3_alt=="MWC" & matchid>1, cluster(expid)
eststo: probit strongcoalition priv_vs_baseline if sq_type3_alt=="UNIVERSAL" & matchid>1, cluster(expid)
eststo: probit strongcoalition pub_vs_baseline if sq_type3_alt=="DICTATOR" & matchid>1, cluster(expid)
eststo: probit strongcoalition pub_vs_baseline if sq_type3_alt=="MWC" & matchid>1, cluster(expid)
eststo: probit strongcoalition pub_vs_baseline if sq_type3_alt=="UNIVERSAL" & matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6, star(* 0.05 ** 0.01) se b(2)
restore

* ROBUSTNESS CHECK #5: ALTERNATIVE DEFINITION OF DURABLE COALITIONS (TABLE 5 IN ONLINE APPENDIX)
* ALLOCATION STABILITY BY TREATMENT
bys treatment: tab weakcoalition if o_type3=="DICTATOR" & index==0 & matchid>1
bys treatment: tab weakcoalition if o_type3=="MWC" & index==0 & matchid>1
bys treatment: tab weakcoalition if o_type3=="UNIVERSAL" & index==0 & matchid>1
* RE PANEL REGRESSIONS CLUSTERING SE AT THE SESSION LEVEL 
preserve
keep if index==0
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg weakcoalition priv_vs_baseline if sq_type3=="DICTATOR" & matchid>1, cluster(expid)
eststo: xtreg weakcoalition priv_vs_baseline if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: xtreg weakcoalition priv_vs_baseline if sq_type3=="UNIVERSAL" & matchid>1, cluster(expid)
eststo: xtreg weakcoalition pub_vs_baseline if sq_type3=="DICTATOR" & matchid>1, cluster(expid)
eststo: xtreg weakcoalition pub_vs_baseline if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: xtreg weakcoalition pub_vs_baseline if sq_type3=="UNIVERSAL" & matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6, star(* 0.05 ** 0.01) se b(2)
restore
* PROBIT REGRESSIONS CLUSTERING SE AT THE SESSION LEVEL 
preserve
keep if index==0
eststo clear
eststo: probit weakcoalition priv_vs_baseline if sq_type3=="DICTATOR" & matchid>1, cluster(expid)
eststo: probit weakcoalition priv_vs_baseline if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: probit weakcoalition priv_vs_baseline if sq_type3=="UNIVERSAL" & matchid>1, cluster(expid)
eststo: probit weakcoalition pub_vs_baseline if sq_type3=="DICTATOR" & matchid>1, cluster(expid)
eststo: probit weakcoalition pub_vs_baseline if sq_type3=="MWC" & matchid>1, cluster(expid)
eststo: probit weakcoalition pub_vs_baseline if sq_type3=="UNIVERSAL" & matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6, star(* 0.05 ** 0.01) se b(2)
restore

*******************************
* TABLE 5 + ROBUSTNESS CHECKS *
*******************************

keep if index==0

sort expid matchid groupid roundid 
gen strongcoalition_counter=.
replace strongcoalition_counter=1 if strongcoalition==1 & strongcoalition[_n-1]!=1
replace strongcoalition_counter=strongcoalition_counter[_n-1]+1 if strongcoalition==1 & strongcoalition[_n-1]==1

sort expid matchid groupid roundid 
gen strongcoalition_id=.
replace strongcoalition_id=_n if strongcoalition==1 & strongcoalition[_n-1]!=1
replace strongcoalition_id=strongcoalition_id[_n-1] if strongcoalition==1 & strongcoalition[_n-1]==1
bys strongcoalition_id: egen strongcoalition_length=max(strongcoalition_counter)
sort expid matchid groupid roundid 
replace strongcoalition_id=_n if strongcoalition_id==.
replace strongcoalition_length=0 if strongcoalition_length==.

sort expid matchid groupid roundid 
gen weakcoalition_counter=.
replace weakcoalition_counter=1 if weakcoalition==1 & weakcoalition[_n-1]!=1
replace weakcoalition_counter=weakcoalition_counter[_n-1]+1 if weakcoalition==1 & weakcoalition[_n-1]==1

sort expid matchid groupid roundid 
gen weakcoalition_id=.
replace weakcoalition_id=_n if weakcoalition==1 & weakcoalition[_n-1]!=1
replace weakcoalition_id=weakcoalition_id[_n-1] if weakcoalition==1 & weakcoalition[_n-1]==1
bys weakcoalition_id: egen weakcoalition_length=max(weakcoalition_counter)
sort expid matchid groupid roundid 
replace weakcoalition_id=_n if weakcoalition_id==.
replace weakcoalition_length=0 if weakcoalition_length==.

* TABLE 5
preserve
bys strongcoalition_id: keep if _n==1
eststo clear
eststo: reg strongcoalition_length privatedummy matchlength if o_type3=="MWC" & strongcoalition_length>0 & matchid>1 & treatment!="PUBLIC", cluster(uniquegroupid)
eststo: reg strongcoalition_length privatedummy matchlength if o_type3=="UNIVERSAL" & strongcoalition_length>0 & matchid>1 & treatment!="PUBLIC", cluster(uniquegroupid)
eststo: reg strongcoalition_length publicdummy matchlength if o_type3=="UNIVERSAL" & strongcoalition_length>0 & matchid>1 & treatment!="PRIVATE", cluster(uniquegroupid)
esttab est1 est2 est3, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2
restore

* ROBUSTNESS CHECK #1: WHOLE SAMPLE (FOOTNOTE 31)
preserve
bys strongcoalition_id: keep if _n==1
eststo clear
eststo: reg strongcoalition_length privatedummy matchlength if o_type3=="MWC" & strongcoalition_length>0 & treatment!="PUBLIC", cluster(uniquegroupid)
eststo: reg strongcoalition_length privatedummy matchlength if o_type3=="UNIVERSAL" & strongcoalition_length>0 & treatment!="PUBLIC", cluster(uniquegroupid)
eststo: reg strongcoalition_length publicdummy matchlength if o_type3=="MWC" & strongcoalition_length>0 & treatment!="PRIVATE", cluster(uniquegroupid)
eststo: reg strongcoalition_length publicdummy matchlength if o_type3=="UNIVERSAL" & strongcoalition_length>0 & treatment!="PRIVATE", cluster(uniquegroupid)
esttab est1 est2 est3 est4, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2
restore

* ROBUSTNESS CHECK #2: ALTERNATIVE CLASSIFICATION OF ALLOCATIONS (TABLE 3 IN ONLINE APPENDIX)
preserve
bys strongcoalition_id: keep if _n==1
eststo clear
eststo: reg strongcoalition_length privatedummy matchlength if o_type3_alt=="MWC" & strongcoalition_length>0 & matchid>1 & treatment!="PUBLIC", cluster(uniquegroupid)
eststo: reg strongcoalition_length privatedummy matchlength if o_type3_alt=="UNIVERSAL" & strongcoalition_length>0 & matchid>1 & treatment!="PUBLIC", cluster(uniquegroupid)
eststo: reg strongcoalition_length publicdummy matchlength if o_type3_alt=="MWC" & strongcoalition_length>0 & matchid>1 & treatment!="PRIVATE", cluster(uniquegroupid)
eststo: reg strongcoalition_length publicdummy matchlength if o_type3_alt=="UNIVERSAL" & strongcoalition_length>0 & matchid>1 & treatment!="PRIVATE", cluster(uniquegroupid)
esttab est1 est2 est3 est4, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2
restore

* ROBUSTNESS CHECK #3: ALTERNATIVE DEFINITION OF DURABLE COALITIONS (TABLE 6 IN ONLINE APPENDIX)
preserve
bys weakcoalition_id: keep if _n==1

eststo clear
eststo: reg weakcoalition_length privatedummy matchlength if o_type3=="MWC" & weakcoalition_length>0 & matchid>1 & treatment!="PUBLIC", cluster(uniquegroupid)
eststo: reg weakcoalition_length privatedummy matchlength if o_type3=="UNIVERSAL" & weakcoalition_length>0 & matchid>1 & treatment!="PUBLIC", cluster(uniquegroupid)
eststo: reg weakcoalition_length publicdummy matchlength if o_type3=="UNIVERSAL" & weakcoalition_length>0 & matchid>1 & treatment!="PRIVATE", cluster(uniquegroupid)
esttab est1 est2 est3, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2
restore

*********************************
* 5.4 ANALYSIS OF CONVERSATIONS *
*********************************

* LOAD RAW DATASET WITH CHAT MESSAGES
* NOTE: NEED TO CHANGE PATH BELOW TO POINT TO DATASET ON LOCAL DRIVE

use "bbn-dynbargchat-chatdata-raw-29aug17.dta", clear
set more off
*ssc install strparse
*ssc install firthlogit

* CODEBOOK FOR RAW DATA VARIABLES 
* NOTE: FOR PERIODS WITH AT LEAST ONE MESSAGE, ONE OBSERVATION FOR EACH MESSAGE; FOR PERIODS WITH NO MESSAGES, A SINGLE OBSERVATION WITH CHOICES AND OUTCOMES
* expid: experimental session ID (1-4)
* matchid: match ID (1-4)
* groupid: group ID
* roundid: round ID
* chatid: message ID (missing for rounds with no messages)
* proposer: index of committee member who proposes in this round
* statusquo: status quo allocation in this round
* proposal: proposed allocation in this round
* voteoutcome: allocation implemented in this period
* sender: index of committee memmber who sent this message
* receiver: index of committee member who received this message ("everyone" for public communication treatment)
* message: content of this message
* keywords: list of keywords from any semantic domain contained in this message (for list of all keywords, see Table x in Appendix x)
* alliance: dummy equal to 1 if this message contains a keyword in the semantic domain "Form a Coalition"
* fairness: dummy equal to 1 if this message contains a keyword in the semantic domain "Lobby for Fairness"
* selfish: dummy equal to 1 if this message contains a keyword in the semantic domain "Lobby for Oneself"
* history: dummy equal to 1 if this message contains a keyword in the semantic domain "History"
* numprop: list of numerical proposals on how to allocate the 60 tokens contained in this message
* numprop20: dummy equal to 1 if this message contains a numerical proposal to allocate the tokens 20-20-20
* numprop30: dummy equal to 1 if this message contains a numerical proposal to allocate the tokens 30-30-0
* numpropother: dummy equal to 1 if this message contains another numerical proposal to allocate the tokens

* CREATION OF VARIABLES FOR ANALYSES

* UNIQUE ID FOR GROUP IN GIVEN GAME OF GIVEN EXPERIMENTAL SESSION
egen uniquegroupid=concat(expid matchid groupid), punct(_)
egen uniquegroupid_num = group(uniquegroupid)

* PARSE STATUS QUO VARIABLE INTO 3 VARIABLES FOR STATUS QUO ALLOCATION TO EACH COMMITTEE MEMBER
gen statusquo2=substr(statusquo,2,.)
gen squarebracket=strpos(statusquo2,"]")
gen statusquo3=substr(statusquo2,1,squarebracket-1)
strparse statusquo3, gen(var) parse( )
destring var1, generate(sq_pork0)
destring var2, generate(sq_pork1)
destring var3, generate(sq_pork2)
drop statusquo2 statusquo3 squarebracket var1 var2 var3

* PARSE PROPOSAL VARIABLE INTO 3 VARIABLES FOR PROPOSED ALLOCATION TO EACH COMMITTEE MEMBER
gen proposal2=substr(proposal,2,.)
gen squarebracket=strpos(proposal2,"]")
gen proposal3=substr(proposal2,1,squarebracket-1)
strparse proposal3, gen(var) parse( )
destring var1, generate(p_pork0)
destring var2, generate(p_pork1)
destring var3, generate(p_pork2)
drop proposal2 proposal3 squarebracket var1 var2 var3

* PARSE VOTE OUTCOME VARIABLE INTO 3 VARIABLES FOR VOTE OUTCOME ALLOCATION TO EACH COMMITTEE MEMBER
gen voteoutcome2=substr(voteoutcome,2,.)
gen squarebracket=strpos(voteoutcome2,"]")
gen voteoutcome3=substr(voteoutcome2,1,squarebracket-1)
strparse voteoutcome3, gen(var) parse( )
destring var1, generate(o_pork0)
destring var2, generate(o_pork1)
destring var3, generate(o_pork2)
drop voteoutcome2 voteoutcome3 squarebracket var1 var2 var3

* VARIABLE FOR TREATMENT ("PUBLIC", "PRIVATE")
gen treatment="PRIVATE"
replace treatment="PUBLIC" if expid<3

* DUMMY FOR PRIVATE TREATMENT
gen privatedummy=0
replace privatedummy=1 if treatment=="PRIVATE"

* DUMMY FOR PUBLIC TREATMENT
gen publicdummy=0
replace publicdummy=1 if treatment=="PUBLIC"

* DUMMIES FOR DIRECTION OF MESSAGE: MSG_X_Y IS DUMMY FOR MESSAGE FROM X TO Y
gen msg_1_all=0
gen msg_2_all=0
gen msg_3_all=0
gen msg_1_2=0
gen msg_1_3=0
gen msg_2_1=0
gen msg_2_3=0
gen msg_3_1=0
gen msg_3_2=0
replace msg_1_all=1 if sender==1 & receiver=="everyone"
replace msg_2_all=1 if sender==2 & receiver=="everyone"
replace msg_3_all=1 if sender==3 & receiver=="everyone"
replace msg_1_2=1 if sender==1 & receiver=="2"
replace msg_1_3=1 if sender==1 & receiver=="3"
replace msg_2_1=1 if sender==2 & receiver=="1"
replace msg_2_3=1 if sender==2 & receiver=="3"
replace msg_3_1=1 if sender==3 & receiver=="1"
replace msg_3_2=1 if sender==3 & receiver=="2"

* VARIABLE FOR OUTCOME TYPE, 5 CATEGORIES
gen o_type5=""
replace o_type5="UNIVERSAL EVEN" if min(o_pork1,o_pork2,o_pork0)==20
replace o_type5="UNIVERSAL UNEVEN" if min(o_pork1,o_pork2,o_pork0)>9 & min(o_pork1,o_pork2,o_pork0)<20
replace o_type5="DICTATOR" if o_pork0>49
replace o_type5="DICTATOR" if o_pork1>49
replace o_type5="DICTATOR" if o_pork2>49
replace o_type5="MWC EVEN" if o_type5=="" & (o_pork0==o_pork1 | o_pork1==o_pork2 | o_pork0==o_pork2)
replace o_type5="MWC UNEVEN" if o_type5=="" 

* VARIABLE FOR OUTCOME TYPE, 3 CATEGORIES
gen o_type3=o_type5
replace o_type3="UNIVERSAL" if o_type5=="UNIVERSAL EVEN"
replace o_type3="UNIVERSAL" if o_type5=="UNIVERSAL UNEVEN"
replace o_type3="MWC" if o_type5=="MWC EVEN"
replace o_type3="MWC" if o_type5=="MWC UNEVEN"

* VARIABLE FOR OUTCOME TYPE, 7 CATEGORIES
gen o_type7=o_type5
replace o_type7="DICTATOR1" if o_pork0>49
replace o_type7="DICTATOR2" if o_pork1>49
replace o_type7="DICTATOR3" if o_pork2>49
replace o_type7="MWC12" if (o_type5=="MWC EVEN" | o_type5=="MWC UNEVEN") & o_pork0>=o_pork2 & o_pork1>=o_pork2
replace o_type7="MWC13" if (o_type5=="MWC EVEN" | o_type5=="MWC UNEVEN") & o_pork0>=o_pork1 & o_pork2>=o_pork1
replace o_type7="MWC23" if (o_type5=="MWC EVEN" | o_type5=="MWC UNEVEN") & o_pork1>=o_pork0 & o_pork2>=o_pork0
replace o_type7="UNIVERSAL" if o_type5=="UNIVERSAL EVEN"
replace o_type7="UNIVERSAL" if o_type5=="UNIVERSAL UNEVEN"

* DUMMIES FOR OUTCOME TYPE
gen o_type_dict=0
replace o_type_dict=1 if o_type3=="DICTATOR"
gen o_type_mwc=0
replace o_type_mwc=1 if o_type3=="MWC"
gen o_type_mwc_even=0
replace o_type_mwc_even=1 if o_type5=="MWC EVEN"
gen o_type_mwc_uneven=0
replace o_type_mwc_uneven=1 if o_type5=="MWC UNEVEN"
gen o_type_u=0
replace o_type_u=1 if o_type3=="UNIVERSAL"
gen o_type_u_even=0
replace o_type_u_even=1 if o_type5=="UNIVERSAL EVEN"
gen o_type_u_uneven=0
replace o_type_u_uneven=1 if o_type5=="UNIVERSAL UNEVEN"

* VARIABLE FOR OUTCOME TYPE, 3 CATEGORIES, ALTERNATIVE CLASSIFICATION
gen o_type3_alt="OTHER"
replace o_type3_alt="UNIVERSAL" if o_pork0>14 & o_pork1>14 & o_pork2>14
replace o_type3_alt="DICTATOR" if o_pork0>49 | o_pork1>49 | o_pork2>49
replace o_type3_alt="MWC" if o_type3_alt=="OTHER" & o_pork1>19 & o_pork2>19 & o_pork0<15
replace o_type3_alt="MWC" if o_type3_alt=="OTHER" & o_pork0>19 & o_pork2>19 & o_pork1<15
replace o_type3_alt="MWC" if o_type3_alt=="OTHER" & o_pork0>19 & o_pork1>19 & o_pork2<15

* VARIABLE FOR OUTCOME TYPE, 5 CATEGORIES, ALTERNATIVE CLASSIFICATION
gen o_type5_alt=o_type3_alt
replace o_type5_alt="UNIVERSAL EVEN" if o_pork0==20 & o_pork1==20 & o_pork2==20
replace o_type5_alt="UNIVERSAL UNEVEN" if o_type5_alt=="UNIVERSAL"
replace o_type5_alt="MWC EVEN" if o_type5_alt=="MWC" & (o_pork0==o_pork1 | o_pork1==o_pork2 | o_pork0==o_pork2)
replace o_type5_alt="MWC UNEVEN" if o_type5_alt=="MWC"

* DUMMIES FOR OUTCOME TYPE, ALTERNATIVE CLASSIFICATION
gen o_type_dict_alt=0
replace o_type_dict_alt=1 if o_type3_alt=="DICTATOR"
gen o_type_mwc_alt=0
replace o_type_mwc_alt=1 if o_type3_alt=="MWC"
gen o_type_mwc_even_alt=0
replace o_type_mwc_even_alt=1 if o_type5_alt=="MWC EVEN"
gen o_type_mwc_uneven_alt=0
replace o_type_mwc_uneven_alt=1 if o_type5_alt=="MWC UNEVEN"
gen o_type_u_alt=0
replace o_type_u_alt=1 if o_type3_alt=="UNIVERSAL"
gen o_type_u_even_alt=0
replace o_type_u_even_alt=1 if o_type5_alt=="UNIVERSAL EVEN"
gen o_type_u_uneven_alt=0
replace o_type_u_uneven_alt=1 if o_type5_alt=="UNIVERSAL UNEVEN"
gen o_type_other_alt=0
replace o_type_other_alt=1 if o_type3_alt=="OTHER"

* VARIABLE FOR STATUS QUO TYPE, 5 CATEGORIES
gen sq_type5=""
replace sq_type5="UNIVERSAL EVEN" if min(sq_pork1,sq_pork2,sq_pork0)==20
replace sq_type5="UNIVERSAL UNEVEN" if min(sq_pork1,sq_pork2,sq_pork0)>9 & min(sq_pork1,sq_pork2,sq_pork0)<20
replace sq_type5="DICTATOR" if sq_pork0>49
replace sq_type5="DICTATOR" if sq_pork1>49
replace sq_type5="DICTATOR" if sq_pork2>49
replace sq_type5="MWC EVEN" if sq_type5=="" & (sq_pork0==sq_pork1 | sq_pork1==sq_pork2 | sq_pork0==sq_pork2)
replace sq_type5="MWC UNEVEN" if sq_type5=="" 

* VARIABLE FOR STATUS QUO TYPE, 7 CATEGORIES
gen sq_type7=sq_type5
replace sq_type7="DICTATOR1" if sq_pork0>49
replace sq_type7="DICTATOR2" if sq_pork1>49
replace sq_type7="DICTATOR3" if sq_pork2>49
replace sq_type7="MWC12" if (sq_type5=="MWC EVEN" | sq_type5=="MWC UNEVEN") & sq_pork0>=sq_pork2 & sq_pork1>=sq_pork2
replace sq_type7="MWC13" if (sq_type5=="MWC EVEN" | sq_type5=="MWC UNEVEN") & sq_pork0>=sq_pork1 & sq_pork2>=sq_pork1
replace sq_type7="MWC23" if (sq_type5=="MWC EVEN" | sq_type5=="MWC UNEVEN") & sq_pork1>=sq_pork0 & sq_pork2>=sq_pork0
replace sq_type7="UNIVERSAL" if sq_type5=="UNIVERSAL EVEN"
replace sq_type7="UNIVERSAL" if sq_type5=="UNIVERSAL UNEVEN"

* VARIABLE FOR STATUS QUO TYPE, 3 CATEGORIES
gen sq_type3=sq_type5
replace sq_type3="UNIVERSAL" if sq_type5=="UNIVERSAL EVEN"
replace sq_type3="UNIVERSAL" if sq_type5=="UNIVERSAL UNEVEN"
replace sq_type3="MWC" if sq_type5=="MWC EVEN"
replace sq_type3="MWC" if sq_type5=="MWC UNEVEN"

* TOTAL NUMBER OF MESSAGES FROM X TO Y IN A GROUP-PERIOD
bys expid matchid groupid roundid: egen totmsg_1_all=sum(msg_1_all)
bys expid matchid groupid roundid: egen totmsg_2_all=sum(msg_2_all)
bys expid matchid groupid roundid: egen totmsg_3_all=sum(msg_3_all)
bys expid matchid groupid roundid: egen totmsg_1_2=sum(msg_1_2)
bys expid matchid groupid roundid: egen totmsg_1_3=sum(msg_1_3)
bys expid matchid groupid roundid: egen totmsg_2_1=sum(msg_2_1)
bys expid matchid groupid roundid: egen totmsg_2_3=sum(msg_2_3)
bys expid matchid groupid roundid: egen totmsg_3_1=sum(msg_3_1)
bys expid matchid groupid roundid: egen totmsg_3_2=sum(msg_3_2)
drop message keywords numprop proposal

* TOTAL NUMBER OF MESSAGES SENT IN A PERIOD
bys expid matchid groupid roundid: egen totmsg=max(chatid)
replace totmsg=0 if totmsg==.
drop chatid

* DUMMIES EQUAL TO 1 IF MESSAGE SENT BY THE PROPOSER AND CONTAINING AT LEAST ONE WORD IN EACH SEMANTIC DOMAIN
gen selfishprop=0
replace selfishprop=selfish if proposer==sender
gen fairnessprop=0
replace fairnessprop=fairness if proposer==sender
gen allianceprop=0
replace allianceprop=alliance if proposer==sender
gen historyprop=0
replace historyprop=history if proposer==sender
gen numprop20prop=0
replace numprop20prop=numprop20 if proposer==sender
gen numprop30prop=0
replace numprop30prop=numprop30 if proposer==sender
gen numpropotherprop=0
replace numpropotherprop=numpropother if proposer==sender

* TOTAL NUMBER OF MESSAGES SENT BY ANY COMMITTEE MEMBER BELONGING TO EACH SEMANTIC DOMAIN IN A GROUP-PERIOD
bys expid matchid groupid roundid: egen selfishmsg=total(selfish)
bys expid matchid groupid roundid: egen fairnessmsg=total(fairness)
bys expid matchid groupid roundid: egen coalitionmsg=total(alliance)
bys expid matchid groupid roundid: egen historymsg=total(history)
bys expid matchid groupid roundid: egen prop20msg=total(numprop20)
bys expid matchid groupid roundid: egen prop30msg=total(numprop30)
bys expid matchid groupid roundid: egen propothermsg=total(numpropother)

* TOTAL NUMBER OF MESSAGES SENT BY PROPOSER BELONGING TO EACH SEMANTIC DOMAIN IN A GROUP-PERIOD
bys expid matchid groupid roundid: egen selfishpropmsg=total(selfishprop)
bys expid matchid groupid roundid: egen fairnesspropmsg=total(fairnessprop)
bys expid matchid groupid roundid: egen coalitionpropmsg=total(allianceprop)
bys expid matchid groupid roundid: egen historypropmsg=total(historyprop)
bys expid matchid groupid roundid: egen prop20propmsg=total(numprop20prop)
bys expid matchid groupid roundid: egen prop30propmsg=total(numprop30prop)
bys expid matchid groupid roundid: egen propotherpropmsg=total(numpropotherprop)

* TOTAL NUMBER OF MESSAGES SENT BY NON-PROPOSERS BELONGING TO EACH SEMANTIC DOMAIN IN A GROUP-PERIOD
gen selfishnopropmsg=selfishmsg-selfishpropmsg
gen fairnessnopropmsg=fairnessmsg-fairnesspropmsg
gen coalitionnopropmsg=coalitionmsg-coalitionpropmsg
gen historynopropmsg=historymsg-historypropmsg
gen prop20nopropmsg=prop20msg-prop20propmsg
gen prop30nopropmsg=prop30msg-prop30propmsg
gen propothernopropmsg=propothermsg-propotherpropmsg

* DUMMY FOR GAMES 2-4
gen latematch=0
replace latematch=1 if matchid>1

* AT THIS POINT AN OBSERVATION OF THIS DATASET IS ONE CHAT MESSAGE
* WE NOW REDUCE THE DATASET TO ONE OBSERVATION FOR EACH GROUP-PERIOD
bys expid matchid groupid roundid: keep if _n==1

drop sender receiver selfish fairness alliance history numprop20 numprop30 numpropother selfishprop fairnessprop allianceprop historyprop numprop20prop numprop30prop numpropotherprop msg_1_all-msg_3_2

gen anymsg=0
replace anymsg=1 if totmsg>0

gen totmsgfromprop=0
replace totmsgfromprop=totmsg_1_all if proposer==1 & treatment=="PUBLIC"
replace totmsgfromprop=totmsg_2_all if proposer==2 & treatment=="PUBLIC"
replace totmsgfromprop=totmsg_3_all if proposer==3 & treatment=="PUBLIC"
replace totmsgfromprop=totmsg_1_2+totmsg_1_3 if proposer==1 & treatment=="PRIVATE"
replace totmsgfromprop=totmsg_2_1+totmsg_2_3 if proposer==2 & treatment=="PRIVATE"
replace totmsgfromprop=totmsg_3_1+totmsg_3_2 if proposer==3 & treatment=="PRIVATE"

gen totmsgfromother=0
replace totmsgfromother=totmsg_2_all+totmsg_3_all if proposer==1 & treatment=="PUBLIC"
replace totmsgfromother=totmsg_1_all+totmsg_3_all if proposer==2 & treatment=="PUBLIC"
replace totmsgfromother=totmsg_2_all+totmsg_1_all if proposer==3 & treatment=="PUBLIC"
replace totmsgfromother=totmsg_2_1+totmsg_2_3+totmsg_3_1+totmsg_3_2 if proposer==1 & treatment=="PRIVATE"
replace totmsgfromother=totmsg_1_2+totmsg_1_3+totmsg_3_1+totmsg_3_2 if proposer==2 & treatment=="PRIVATE"
replace totmsgfromother=totmsg_2_1+totmsg_2_3+totmsg_1_2+totmsg_1_3 if proposer==3 & treatment=="PRIVATE"

gen totmsgfromothertoother=.
replace totmsgfromothertoother=totmsg_2_3+totmsg_3_2 if proposer==1 & treatment=="PRIVATE"
replace totmsgfromothertoother=totmsg_1_3+totmsg_3_1 if proposer==2 & treatment=="PRIVATE"
replace totmsgfromothertoother=totmsg_2_1+totmsg_1_2 if proposer==3 & treatment=="PRIVATE"

gen totmsgfromothertoprop=.
replace totmsgfromothertoprop=totmsg_2_1+totmsg_3_1 if proposer==1 & treatment=="PRIVATE"
replace totmsgfromothertoprop=totmsg_1_2+totmsg_3_2 if proposer==2 & treatment=="PRIVATE"
replace totmsgfromothertoprop=totmsg_1_3+totmsg_2_3 if proposer==3 & treatment=="PRIVATE"

gen anyselfishmsg=0
replace anyselfishmsg=1 if selfishmsg>0
gen anyfairnessmsg=0
replace anyfairnessmsg=1 if fairnessmsg>0
gen anycoalitionmsg=0
replace anycoalitionmsg=1 if coalitionmsg>0
gen anyhistorymsg=0
replace anyhistorymsg=1 if historymsg>0
gen anyprop30msg=0
replace anyprop30msg=1 if prop30msg>0
gen anyprop20msg=0
replace anyprop20msg=1 if prop20msg>0
gen anypropothermsg=0
replace anypropothermsg=1 if propothermsg>0
gen anyselfishpropmsg=0
replace anyselfishpropmsg=1 if selfishpropmsg>0
gen anyfairnesspropmsg=0
replace anyfairnesspropmsg=1 if fairnesspropmsg>0
gen anycoalitionpropmsg=0
replace anycoalitionpropmsg=1 if coalitionpropmsg>0
gen anyhistorypropmsg=0
replace anyhistorypropmsg=1 if historypropmsg>0
gen anyprop30propmsg=0
replace anyprop30propmsg=1 if prop30propmsg>0
gen anyprop20propmsg=0
replace anyprop20propmsg=1 if prop20propmsg>0
gen anypropotherpropmsg=0
replace anypropotherpropmsg=1 if propotherpropmsg>0
gen anyselfishnopropmsg=0
replace anyselfishnopropmsg=1 if selfishnopropmsg>0
gen anyfairnessnopropmsg=0
replace anyfairnessnopropmsg=1 if fairnessnopropmsg>0
gen anycoalitionnopropmsg=0
replace anycoalitionnopropmsg=1 if coalitionnopropmsg>0
gen anyhistorynopropmsg=0
replace anyhistorynopropmsg=1 if historynopropmsg>0
gen anyprop30nopropmsg=0
replace anyprop30nopropmsg=1 if prop30nopropmsg>0
gen anyprop20nopropmsg=0
replace anyprop20nopropmsg=1 if prop20nopropmsg>0
gen anypropothernopropmsg=0
replace anypropothernopropmsg=1 if propothernopropmsg>0

************
* TABLE 7 *
***********

* TABLE 7
* USE OF COMMUNICATION BY TREATMENT
bys treatment: su anymsg totmsg totmsgfromprop totmsgfromother totmsgfromothertoprop totmsgfromothertoother if matchid>1
bys treatment: su anymsg totmsg if roundid==1 & matchid>1
* RE PANEL REGRESSIONS CLUSTERING SE BY SESSION
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg anymsg privatedummy if matchid>1, cluster(expid)
eststo: reg anymsg privatedummy if roundid==1 & matchid>1, cluster(expid)
eststo: xtreg totmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg totmsgfromprop privatedummy if matchid>1, cluster(expid)
eststo: xtreg totmsgfromother privatedummy if matchid>1, cluster(expid)
eststo: reg totmsg privatedummy if roundid==1 & matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6, star(* 0.05 ** 0.01) se b(2) pr2

***********
* TABLE 8 *
***********

preserve
gen totmsg_12=totmsg_1_2+totmsg_2_1
gen totmsg_13=totmsg_1_3+totmsg_3_1
gen totmsg_23=totmsg_2_3+totmsg_3_2
gen o_pork12=o_pork0+o_pork1
gen o_pork13=o_pork0+o_pork2
gen o_pork23=o_pork1+o_pork2
gen sq_pork12=sq_pork0+sq_pork1
gen sq_pork13=sq_pork0+sq_pork2
gen sq_pork23=sq_pork1+sq_pork2
gen ineq12=((o_pork0/o_pork12-0.5)^2+(o_pork1/o_pork12-0.5)^2)^0.5
gen ineq13=((o_pork0/o_pork13-0.5)^2+(o_pork2/o_pork13-0.5)^2)^0.5
gen ineq23=((o_pork1/o_pork23-0.5)^2+(o_pork2/o_pork23-0.5)^2)^0.5
gen sqineq12=((sq_pork0/sq_pork12-0.5)^2+(sq_pork1/sq_pork12-0.5)^2)^0.5
gen sqineq13=((sq_pork0/sq_pork13-0.5)^2+(sq_pork2/sq_pork13-0.5)^2)^0.5
gen sqineq23=((sq_pork1/sq_pork23-0.5)^2+(sq_pork2/sq_pork23-0.5)^2)^0.5

keep sqineq12 sqineq13 sqineq23 ineq12 ineq13 ineq23 expid matchid groupid roundid uniquegroupid proposer treatment totmsg_12 totmsg_13 totmsg_23 o_pork12 o_pork13 o_pork23 sq_pork12 sq_pork13 sq_pork23

rename totmsg_12 msg12
rename totmsg_13 msg13
rename totmsg_23 msg23
rename sq_pork12 sq12
rename sq_pork13 sq13
rename sq_pork23 sq23
rename o_pork12 o12
rename o_pork13 o13
rename o_pork23 o23

egen uniqueid=concat(expid matchid groupid roundid), punct(_)
reshape long sq sqineq o msg ineq, i(uniqueid) j(pair)
drop uniqueid

* TABLE 8, COLUMNS 1 & 2
egen uniquepairid = group(uniquegroupid pair)
xtset uniquepairid roundid
eststo clear
eststo: xtreg o sq msg if treatment=="PRIVATE" & matchid>1, cluster(expid)
eststo: xtreg ineq sqineq msg if treatment=="PRIVATE" & matchid>1, cluster(expid)
esttab est1 est2, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2
restore

* TABLE 8, COLUMN 3
preserve
keep if treatment=="PUBLIC"
gen ineq123=((o_pork0/60-(1/3))^2+(o_pork1/60-(1/3))^2+(o_pork2/60-(1/3)))^0.5
gen sqineq123=((sq_pork0/60-(1/3))^2+(sq_pork1/60-(1/3))^2+(sq_pork2/60-(1/3)))^0.5
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg ineq sqineq totmsg if matchid>1, cluster(expid)
esttab est1, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2
restore

*******************************
* TABLE 9 + ROBUSTNESS CHECKS *
*******************************

* TABLE 9
* COMPARISON BETWEEN TREATMENTS
bys treatment: su selfishmsg fairnessmsg coalitionmsg historymsg prop20msg prop30msg propothermsg if matchid>1
bys treatment: su selfishpropmsg fairnesspropmsg coalitionpropmsg historypropmsg prop20propmsg prop30propmsg propotherpropmsg if matchid>1
bys treatment: su selfishnopropmsg fairnessnopropmsg coalitionnopropmsg historynopropmsg prop20nopropmsg prop30nopropmsg propothernopropmsg if matchid>1
* RE PANEL REGRESSIONS CLUSTERING SE BY SESSION
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg selfishmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg fairnessmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg coalitionmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg historymsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg prop20msg privatedummy if matchid>1, cluster(expid)
eststo: xtreg prop30msg privatedummy if matchid>1, cluster(expid)
eststo: xtreg propothermsg privatedummy if matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2
eststo clear
eststo: xtreg selfishpropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg fairnesspropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg coalitionpropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg historypropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg prop20propmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg prop30propmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg propotherpropmsg privatedummy if matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7, star(* 0.05 ** 0.01) se b(2) pr2
eststo clear
eststo: xtreg selfishnopropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg fairnessnopropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg coalitionnopropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg historynopropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg prop20nopropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg prop30nopropmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg propothernopropmsg privatedummy if matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7, star(* 0.05 ** 0.01) se b(2) pr2

* ROBUSTNESS CHECK: ALL SAMPLE (FOOTNOTE 37)
* RE PANEL REGRESSIONS CLUSTERING SE BY SESSION
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg selfishmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg fairnessmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg coalitionmsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg historymsg privatedummy if matchid>1, cluster(expid)
eststo: xtreg prop20msg privatedummy if matchid>1, cluster(expid)
eststo: xtreg prop30msg privatedummy if matchid>1, cluster(expid)
eststo: xtreg propothermsg privatedummy if matchid>1, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7, star(* 0.05 ** 0.01) se b(2) pr2

* COMPARISON BETWEEN GAME 1 AND GAMES 2-4 (FOOTNOTE 37)
* RE PANEL REGRESSIONS CLUSTERING SE BY SESSION
xtset uniquegroupid_num roundid
eststo clear
eststo: xtreg selfishmsg latematch if privatedummy==1, cluster(expid)
eststo: xtreg fairnessmsg latematch if privatedummy==1, cluster(expid)
eststo: xtreg coalitionmsg latematch if privatedummy==1, cluster(expid)
eststo: xtreg historymsg latematch if privatedummy==1, cluster(expid)
eststo: xtreg prop20msg latematch if privatedummy==1, cluster(expid)
eststo: xtreg prop30msg latematch if privatedummy==1, cluster(expid)
eststo: xtreg propothermsg latematch if privatedummy==1, cluster(expid)
eststo: xtreg selfishmsg latematch if privatedummy==0, cluster(expid)
eststo: xtreg fairnessmsg latematch if privatedummy==0, cluster(expid)
eststo: xtreg coalitionmsg latematch if privatedummy==0, cluster(expid)
eststo: xtreg historymsg latematch if privatedummy==0, cluster(expid)
eststo: xtreg prop20msg latematch if privatedummy==0, cluster(expid)
eststo: xtreg prop30msg latematch if privatedummy==0, cluster(expid)
eststo: xtreg propothermsg latematch if privatedummy==0, cluster(expid)
esttab est1 est2 est3 est4 est5 est6 est7, star(* 0.05 ** 0.01) se b(2) pr2
esttab est8 est9 est10 est11 est12 est13 est14, star(* 0.05 ** 0.01) se b(2) pr2

********************************
* TABLE 10 + ROBUSTNESS CHECKS *
********************************

* TABLE 10
eststo clear
eststo: firthlogit o_type_u anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict==0  & treatment=="PRIVATE"
eststo: firthlogit o_type_u anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict==0  & treatment=="PUBLIC"
eststo: firthlogit o_type_u anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict==0 & matchid>1  & treatment=="PRIVATE"
eststo: firthlogit o_type_u anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict==0 & matchid>1  & treatment=="PUBLIC"
esttab est1 est2 est3 est4, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2

* THE COMMAND FIRTHLOGIT DOES NOT PROVIDE A PSEUDO R-SQUARE
* THE CODE BELOW GENERATES A MEASURE SIMILAR TO A PSEUDO R-SQUARE
firthlogit  o_type_u anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict==0  & treatment=="PRIVATE"
predict var91 if e(sample)
corr o_type_u var91 if e(sample) 
di r(rho)^2
firthlogit  o_type_u anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict==0  & treatment=="PUBLIC"
predict var92 if e(sample)
corr o_type_u var92 if e(sample) 
di r(rho)^2
firthlogit  o_type_u anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict==0 & matchid>1  & treatment=="PRIVATE"
predict var93 if e(sample)
corr o_type_u var93 if e(sample) 
di r(rho)^2
firthlogit  o_type_u anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict==0 & matchid>1  & treatment=="PUBLIC"
predict var94 if e(sample)
corr o_type_u var94 if e(sample) 
di r(rho)^2

* ROBUSTNESS CHECK: ALTERNATIVE CLASSIFICATION OF ALLOCATIONS (TABLE 4 IN ONLINE APPENDIX)
eststo clear
eststo: firthlogit  o_type_u_alt anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict_alt==0  & treatment=="PRIVATE"
eststo: firthlogit  o_type_u_alt anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict_alt==0  & treatment=="PUBLIC"
eststo: firthlogit  o_type_u_alt anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict_alt==0 & matchid>1  & treatment=="PRIVATE"
eststo: firthlogit  o_type_u_alt anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict_alt==0 & matchid>1  & treatment=="PUBLIC"
esttab est1 est2 est3 est4, star(* 0.10 ** 0.05 *** 0.01) se b(2) pr2

* THE COMMAND FIRTHLOGIT DOES NOT PROVIDE A PSEUDO R-SQUARE
* THE CODE BELOW GENERATES A MEASURE SIMILAR TO A PSEUDO R-SQUARE
firthlogit  o_type_u_alt anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict_alt==0  & treatment=="PRIVATE"
predict var101 if e(sample)
corr o_type_u var101 if e(sample) 
di r(rho)^2
firthlogit  o_type_u_alt anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict_alt==0  & treatment=="PUBLIC"
predict var102 if e(sample)
corr o_type_u var102 if e(sample) 
di r(rho)^2
firthlogit  o_type_u_alt anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict_alt==0 & matchid>1  & treatment=="PRIVATE"
predict var103 if e(sample)
corr o_type_u var103 if e(sample) 
di r(rho)^2
firthlogit  o_type_u_alt anymsg anyselfishnopropmsg anyfairnessnopropmsg anycoalitionnopropmsg anyhistorynopropmsg anyprop20nopropmsg anyprop30nopropmsg anyselfishpropmsg anyfairnesspropmsg anycoalitionpropmsg anyhistorypropmsg anyprop20propmsg anyprop30propmsg if o_type_dict_alt==0 & matchid>1  & treatment=="PUBLIC"
predict var104 if e(sample)
corr o_type_u var104 if e(sample) 
di r(rho)^2
